@@ -1,13 +1,29 @@
 <?php
 /**
- * Media Library List Table class.
+ * List Table API: WP_Media_List_Table class
  *
  * @package WordPress
- * @subpackage List_Table
+ * @subpackage Administration
+ * @since 3.1.0
+ */
+
+/**
+ * Core class used to implement displaying media items in a list table.
+ *
  * @since 3.1.0
  * @access private
+ *
+ * @see WP_List_Table
  */
 class WP_Media_List_Table extends WP_List_Table {
+	/**
+	 * Holds the number of pending comments for each post.
+	 *
+	 * @since 4.4.0
+	 * @var array
+	 * @access protected
+	 */
+	protected $comment_pending_count = array();
 
 	private $detached;
 
@@ -57,7 +73,7 @@ class WP_Media_List_Table extends WP_List_Table {
 
 		list( $post_mime_types, $avail_post_mime_types ) = wp_edit_attachments_query( $_REQUEST );
 
- 		$this->is_trash = isset( $_REQUEST['attachment-filter'] ) && 'trash' == $_REQUEST['attachment-filter'];
+ 		$this->is_trash = isset( $_REQUEST['attachment-filter'] ) && 'trash' === $_REQUEST['attachment-filter'];
 
  		$mode = empty( $_REQUEST['mode'] ) ? 'list' : $_REQUEST['mode'];
 
@@ -69,43 +85,51 @@ class WP_Media_List_Table extends WP_List_Table {
 	}
 
 	/**
-	 *
-	 * @global wpdb  $wpdb
 	 * @global array $post_mime_types
 	 * @global array $avail_post_mime_types
 	 * @return array
 	 */
 	protected function get_views() {
-		global $wpdb, $post_mime_types, $avail_post_mime_types;
+		global $post_mime_types, $avail_post_mime_types;
 
 		$type_links = array();
-		$_num_posts = (array) wp_count_attachments();
-		$_total_posts = array_sum($_num_posts) - $_num_posts['trash'];
-		$total_orphans = $wpdb->get_var( "SELECT COUNT( * ) FROM $wpdb->posts WHERE post_type = 'attachment' AND post_status != 'trash' AND post_parent < 1" );
-		$matches = wp_match_mime_types(array_keys($post_mime_types), array_keys($_num_posts));
-		$num_posts = array();
-		foreach ( $matches as $type => $reals ) {
-			foreach ( $reals as $real ) {
-				$num_posts[$type] = ( isset( $num_posts[$type] ) ) ? $num_posts[$type] + $_num_posts[$real] : $_num_posts[$real];
-			}
-		}
-		$selected = empty( $_GET['attachment-filter'] ) ? ' selected="selected"' : '';
-		$type_links['all'] = "<option value=''$selected>" . sprintf( _nx( 'All (%s)', 'All (%s)', $_total_posts, 'uploaded files' ), number_format_i18n( $_total_posts ) ) . '</option>';
+
+		$filter = empty( $_GET['attachment-filter'] ) ? '' : $_GET['attachment-filter'];
+
+		$type_links['all'] = sprintf(
+			'<option value=""%s>%s</option>',
+			selected( $filter, true, false ),
+			__( 'All media items' )
+		);
+
 		foreach ( $post_mime_types as $mime_type => $label ) {
-			if ( !wp_match_mime_types($mime_type, $avail_post_mime_types) )
+			if ( ! wp_match_mime_types( $mime_type, $avail_post_mime_types ) ) {
 				continue;
+			}
 
-			$selected = '';
-			if ( !empty( $_GET['attachment-filter'] ) && strpos( $_GET['attachment-filter'], 'post_mime_type:' ) === 0 && wp_match_mime_types( $mime_type, str_replace( 'post_mime_type:', '', $_GET['attachment-filter'] ) ) )
-				$selected = ' selected="selected"';
-			if ( !empty( $num_posts[$mime_type] ) )
-				$type_links[$mime_type] = '<option value="post_mime_type:' . esc_attr( $mime_type ) . '"' . $selected . '>' . sprintf( translate_nooped_plural( $label[2], $num_posts[$mime_type] ), number_format_i18n( $num_posts[$mime_type] )) . '</option>';
+			$selected = selected(
+				$filter && 0 === strpos( $filter, 'post_mime_type:' ) &&
+					wp_match_mime_types( $mime_type, str_replace( 'post_mime_type:', '', $filter ) ),
+				true,
+				false
+			);
+
+			$type_links[$mime_type] = sprintf(
+				'<option value="post_mime_type:%s"%s>%s</option>',
+				esc_attr( $mime_type ),
+				$selected,
+				$label[0]
+			);
 		}
-		$type_links['detached'] = '<option value="detached"' . ( $this->detached ? ' selected="selected"' : '' ) . '>' . sprintf( _nx( 'Unattached (%s)', 'Unattached (%s)', $total_orphans, 'detached files' ), number_format_i18n( $total_orphans ) ) . '</option>';
-
-		if ( !empty($_num_posts['trash']) )
-			$type_links['trash'] = '<option value="trash"' . ( (isset($_GET['attachment-filter']) && $_GET['attachment-filter'] == 'trash' ) ? ' selected="selected"' : '') . '>' . sprintf( _nx( 'Trash (%s)', 'Trash (%s)', $_num_posts['trash'], 'uploaded files' ), number_format_i18n( $_num_posts['trash'] ) ) . '</option>';
+		$type_links['detached'] = '<option value="detached"' . ( $this->detached ? ' selected="selected"' : '' ) . '>' . __( 'Unattached' ) . '</option>';
 
+		if ( $this->is_trash || ( defined( 'MEDIA_TRASH') && MEDIA_TRASH ) ) {
+			$type_links['trash'] = sprintf(
+				'<option value="trash"%s>%s</option>',
+				selected( 'trash' === $filter, true, false ),
+				_x( 'Trash', 'attachment filter' )
+			);
+		}
 		return $type_links;
 	}
 
@@ -120,14 +144,14 @@ class WP_Media_List_Table extends WP_List_Table {
 				$actions['untrash'] = __( 'Restore' );
 				$actions['delete'] = __( 'Delete Permanently' );
 			} else {
-				$actions['trash'] = __( 'Trash' );
+				$actions['trash'] = _x( 'Trash', 'verb' );
 			}
 		} else {
 			$actions['delete'] = __( 'Delete Permanently' );
 		}
 
 		if ( $this->detached )
-			$actions['attach'] = __( 'Attach to a post' );
+			$actions['attach'] = __( 'Attach' );
 
 		return $actions;
 	}
@@ -148,7 +172,8 @@ class WP_Media_List_Table extends WP_List_Table {
 			}
 
 			/** This action is documented in wp-admin/includes/class-wp-posts-list-table.php */
-			do_action( 'restrict_manage_posts' );
+			do_action( 'restrict_manage_posts', $this->screen->post_type );
+
 			submit_button( __( 'Filter' ), 'button', 'filter_action', false, array( 'id' => 'post-query-submit' ) );
 		}
 
@@ -188,7 +213,7 @@ class WP_Media_List_Table extends WP_List_Table {
 	 * @access public
 	 */
 	public function no_items() {
-		_e( 'No media attachments found.' );
+		_e( 'No media files found.' );
 	}
 
 	/**
@@ -200,6 +225,8 @@ class WP_Media_List_Table extends WP_List_Table {
 		global $mode;
 
 		$views = $this->get_views();
+
+		$this->screen->render_screen_reader_content( 'heading_views' );
 ?>
 <div class="wp-filter">
 	<div class="filter-items">
@@ -266,13 +293,13 @@ class WP_Media_List_Table extends WP_List_Table {
 		$taxonomies = array_filter( $taxonomies, 'taxonomy_exists' );
 
 		foreach ( $taxonomies as $taxonomy ) {
-			if ( 'category' == $taxonomy )
+			if ( 'category' === $taxonomy ) {
 				$column_key = 'categories';
-			elseif ( 'post_tag' == $taxonomy )
+			} elseif ( 'post_tag' === $taxonomy ) {
 				$column_key = 'tags';
-			else
+			} else {
 				$column_key = 'taxonomy-' . $taxonomy;
-
+			}
 			$posts_columns[ $column_key ] = get_taxonomy( $taxonomy )->labels->name;
 		}
 
@@ -343,25 +370,34 @@ class WP_Media_List_Table extends WP_List_Table {
 		$link_start = $link_end = '';
 
 		if ( current_user_can( 'edit_post', $post->ID ) && ! $this->is_trash ) {
-			$link_start = '<a href="' . get_edit_post_link( $post->ID ) . '">';
+			$link_start = sprintf(
+				'<a href="%s" aria-label="%s">',
+				get_edit_post_link( $post->ID ),
+				/* translators: %s: attachment title */
+				esc_attr( sprintf( __( '&#8220;%s&#8221; (Edit)' ), $title ) )
+			);
 			$link_end = '</a>';
 		}
 
 		$class = $thumb ? ' class="has-media-icon"' : '';
-
 		?>
 		<strong<?php echo $class; ?>>
-			<?php echo $link_start; ?>
-				<?php if ( $thumb ) : ?>
+			<?php
+			echo $link_start;
+			if ( $thumb ) : ?>
 				<span class="media-icon <?php echo sanitize_html_class( $mime . '-icon' ); ?>"><?php echo $thumb; ?></span>
-				<?php endif; ?>
-
-				<span aria-hidden="true"><?php echo $title; ?></span>
-				<span class="screen-reader-text"><?php printf( __( 'Edit &#8220;%s&#8221;' ), $title ); ?></span>
-			<?php echo $link_end; ?>
-			<?php _media_states( $post ); ?>
+			<?php endif;
+			echo $title . $link_end;
+			_media_states( $post );
+			?>
 		</strong>
-		<p class="filename"><span class="screen-reader-text"><?php _e( 'File name:' ); ?> </span><?php echo wp_basename( $post->guid ); ?></p>
+		<p class="filename">
+			<span class="screen-reader-text"><?php _e( 'File name:' ); ?> </span>
+			<?php
+			$file = get_attached_file( $post->ID );
+			echo esc_html( wp_basename( $file ) );
+			?>
+		</p>
 		<?php
 	}
 
@@ -401,7 +437,7 @@ class WP_Media_List_Table extends WP_List_Table {
 	 * @param WP_Post $post The current WP_Post object.
 	 */
 	public function column_date( $post ) {
-		if ( '0000-00-00 00:00:00' == $post->post_date ) {
+		if ( '0000-00-00 00:00:00' === $post->post_date ) {
 			$h_time = __( 'Unpublished' );
 		} else {
 			$m_time = $post->post_date;
@@ -447,25 +483,35 @@ class WP_Media_List_Table extends WP_List_Table {
 					<?php echo $title ?></a><?php
 			} else {
 				echo $title;
-			} ?></strong>,
-			<?php echo get_the_time( __( 'Y/m/d' ) ); ?><br />
+			} ?></strong>
+			<br />
 			<?php
 			if ( $user_can_edit ):
 				$detach_url = add_query_arg( array(
 					'parent_post_id' => $post->post_parent,
 					'media[]' => $post->ID,
 					'_wpnonce' => wp_create_nonce( 'bulk-' . $this->_args['plural'] )
-				), 'upload.php' ); ?>
-			<a class="hide-if-no-js detach-from-parent" href="<?php echo $detach_url ?>"><?php _e( 'Detach' ); ?></a>
-			<?php endif;
+				), 'upload.php' );
+				printf(
+					'<a href="%s" class="hide-if-no-js detach-from-parent" aria-label="%s">%s</a>',
+					$detach_url,
+					/* translators: %s: title of the post the attachment is attached to */
+					esc_attr( sprintf( __( 'Detach from &#8220;%s&#8221;' ), $title ) ),
+					__( 'Detach' )
+				);
+			endif;
 		} else {
 			_e( '(Unattached)' ); ?><br />
-			<?php if ( $user_can_edit ) { ?>
-				<a class="hide-if-no-js"
-					onclick="findPosts.open( 'media[]','<?php echo $post->ID ?>' ); return false;"
-					href="#the-list">
-					<?php _e( 'Attach' ); ?></a>
-			<?php }
+			<?php if ( $user_can_edit ) {
+				$title = _draft_or_post_title( $post->post_parent );
+				printf(
+					'<a href="#the-list" onclick="findPosts.open( \'media[]\', \'%s\' ); return false;" class="hide-if-no-js" aria-label="%s">%s</a>',
+					$post->ID,
+					/* translators: %s: attachment title */
+					esc_attr( sprintf( __( 'Attach &#8220;%s&#8221; to existing content' ), $title ) ),
+					__( 'Attach' )
+				);
+			}
 		}
 	}
 
@@ -480,7 +526,12 @@ class WP_Media_List_Table extends WP_List_Table {
 	public function column_comments( $post ) {
 		echo '<div class="post-com-count-wrapper">';
 
-		$pending_comments = get_pending_comments_num( $post->ID );
+		if ( isset( $this->comment_pending_count[ $post->ID ] ) ) {
+			$pending_comments = $this->comment_pending_count[ $post->ID ];
+		} else {
+			$pending_comments = get_pending_comments_num( $post->ID );
+		}
+
 		$this->comments_bubble( $post->ID, $pending_comments );
 
 		echo '</div>';
@@ -496,9 +547,9 @@ class WP_Media_List_Table extends WP_List_Table {
 	 * @param string  $column_name Current column name.
 	 */
 	public function column_default( $post, $column_name ) {
-		if ( 'categories' == $column_name ) {
+		if ( 'categories' === $column_name ) {
 			$taxonomy = 'category';
-		} elseif ( 'tags' == $column_name ) {
+		} elseif ( 'tags' === $column_name ) {
 			$taxonomy = 'post_tag';
 		} elseif ( 0 === strpos( $column_name, 'taxonomy-' ) ) {
 			$taxonomy = substr( $column_name, 9 );
@@ -547,14 +598,19 @@ class WP_Media_List_Table extends WP_List_Table {
 	 * @global WP_Post $post
 	 */
 	public function display_rows() {
-		global $post;
+		global $post, $wp_query;
+
+		$post_ids = wp_list_pluck( $wp_query->posts, 'ID' );
+		reset( $wp_query->posts );
+
+		$this->comment_pending_count = get_pending_comments_num( $post_ids );
 
 		add_filter( 'the_title','esc_html' );
 
 		while ( have_posts() ) : the_post();
 			if (
 				( $this->is_trash && $post->post_status != 'trash' )
-				|| ( ! $this->is_trash && $post->post_status == 'trash' )
+				|| ( ! $this->is_trash && $post->post_status === 'trash' )
 			) {
 				continue;
 			}
@@ -589,35 +645,102 @@ class WP_Media_List_Table extends WP_List_Table {
 		$actions = array();
 
 		if ( $this->detached ) {
-			if ( current_user_can( 'edit_post', $post->ID ) )
-				$actions['edit'] = '<a href="' . get_edit_post_link( $post->ID ) . '">' . __( 'Edit' ) . '</a>';
-			if ( current_user_can( 'delete_post', $post->ID ) )
-				if ( EMPTY_TRASH_DAYS && MEDIA_TRASH ) {
-					$actions['trash'] = "<a class='submitdelete' href='" . wp_nonce_url( "post.php?action=trash&amp;post=$post->ID", 'trash-post_' . $post->ID ) . "'>" . __( 'Trash' ) . "</a>";
-				} else {
-					$delete_ays = !MEDIA_TRASH ? " onclick='return showNotice.warn();'" : '';
-					$actions['delete'] = "<a class='submitdelete'$delete_ays href='" . wp_nonce_url( "post.php?action=delete&amp;post=$post->ID", 'delete-post_' . $post->ID ) . "'>" . __( 'Delete Permanently' ) . "</a>";
-				}
-			$actions['view'] = '<a href="' . get_permalink( $post->ID ) . '" title="' . esc_attr( sprintf( __( 'View &#8220;%s&#8221;' ), $att_title ) ) . '" rel="permalink">' . __( 'View' ) . '</a>';
-			if ( current_user_can( 'edit_post', $post->ID ) )
-				$actions['attach'] = '<a href="#the-list" onclick="findPosts.open( \'media[]\',\''.$post->ID.'\' );return false;" class="hide-if-no-js">'.__( 'Attach' ).'</a>';
-		}
-		else {
-			if ( current_user_can( 'edit_post', $post->ID ) && !$this->is_trash )
-				$actions['edit'] = '<a href="' . get_edit_post_link( $post->ID ) . '">' . __( 'Edit' ) . '</a>';
+			if ( current_user_can( 'edit_post', $post->ID ) ) {
+				$actions['edit'] = sprintf(
+					'<a href="%s" aria-label="%s">%s</a>',
+					get_edit_post_link( $post->ID ),
+					/* translators: %s: attachment title */
+					esc_attr( sprintf( __( 'Edit &#8220;%s&#8221;' ), $att_title ) ),
+					__( 'Edit' )
+				);
+			}
 			if ( current_user_can( 'delete_post', $post->ID ) ) {
-				if ( $this->is_trash )
-					$actions['untrash'] = "<a class='submitdelete' href='" . wp_nonce_url( "post.php?action=untrash&amp;post=$post->ID", 'untrash-post_' . $post->ID ) . "'>" . __( 'Restore' ) . "</a>";
-				elseif ( EMPTY_TRASH_DAYS && MEDIA_TRASH )
-					$actions['trash'] = "<a class='submitdelete' href='" . wp_nonce_url( "post.php?action=trash&amp;post=$post->ID", 'trash-post_' . $post->ID ) . "'>" . __( 'Trash' ) . "</a>";
-				if ( $this->is_trash || !EMPTY_TRASH_DAYS || !MEDIA_TRASH ) {
-					$delete_ays = ( !$this->is_trash && !MEDIA_TRASH ) ? " onclick='return showNotice.warn();'" : '';
-					$actions['delete'] = "<a class='submitdelete'$delete_ays href='" . wp_nonce_url( "post.php?action=delete&amp;post=$post->ID", 'delete-post_' . $post->ID ) . "'>" . __( 'Delete Permanently' ) . "</a>";
+				if ( EMPTY_TRASH_DAYS && MEDIA_TRASH ) {
+					$actions['trash'] = sprintf(
+						'<a href="%s" class="submitdelete" aria-label="%s">%s</a>',
+						wp_nonce_url( "post.php?action=trash&amp;post=$post->ID", 'trash-post_' . $post->ID ),
+						/* translators: %s: attachment title */
+						esc_attr( sprintf( __( 'Move &#8220;%s&#8221; to the Trash' ), $att_title ) ),
+						_x( 'Trash', 'verb' )
+					);
+				} else {
+					$delete_ays = ! MEDIA_TRASH ? " onclick='return showNotice.warn();'" : '';
+					$actions['delete'] = sprintf(
+						'<a href="%s" class="submitdelete"%s aria-label="%s">%s</a>',
+						wp_nonce_url( "post.php?action=delete&amp;post=$post->ID", 'delete-post_' . $post->ID ),
+						$delete_ays,
+						/* translators: %s: attachment title */
+						esc_attr( sprintf( __( 'Delete &#8220;%s&#8221; permanently' ), $att_title ) ),
+						__( 'Delete Permanently' )
+					);
 				}
 			}
-			if ( !$this->is_trash ) {
-				$title =_draft_or_post_title( $post->post_parent );
-				$actions['view'] = '<a href="' . get_permalink( $post->ID ) . '" title="' . esc_attr( sprintf( __( 'View &#8220;%s&#8221;' ), $title ) ) . '" rel="permalink">' . __( 'View' ) . '</a>';
+			$actions['view'] = sprintf(
+				'<a href="%s" aria-label="%s" rel="permalink">%s</a>',
+				get_permalink( $post->ID ),
+				/* translators: %s: attachment title */
+				esc_attr( sprintf( __( 'View &#8220;%s&#8221;' ), $att_title ) ),
+				__( 'View' )
+			);
+
+			if ( current_user_can( 'edit_post', $post->ID ) ) {
+				$actions['attach'] = sprintf(
+					'<a href="#the-list" onclick="findPosts.open( \'media[]\', \'%s\' ); return false;" class="hide-if-no-js" aria-label="%s">%s</a>',
+					$post->ID,
+					/* translators: %s: attachment title */
+					esc_attr( sprintf( __( 'Attach &#8220;%s&#8221; to existing content' ), $att_title ) ),
+					__( 'Attach' )
+				);
+			}
+		}
+		else {
+			if ( current_user_can( 'edit_post', $post->ID ) && !$this->is_trash ) {
+				$actions['edit'] = sprintf(
+					'<a href="%s" aria-label="%s">%s</a>',
+					get_edit_post_link( $post->ID ),
+					/* translators: %s: attachment title */
+					esc_attr( sprintf( __( 'Edit &#8220;%s&#8221;' ), $att_title ) ),
+					__( 'Edit' )
+				);
+			}
+			if ( current_user_can( 'delete_post', $post->ID ) ) {
+				if ( $this->is_trash ) {
+					$actions['untrash'] = sprintf(
+						'<a href="%s" class="submitdelete" aria-label="%s">%s</a>',
+						wp_nonce_url( "post.php?action=untrash&amp;post=$post->ID", 'untrash-post_' . $post->ID ),
+						/* translators: %s: attachment title */
+						esc_attr( sprintf( __( 'Restore &#8220;%s&#8221; from the Trash' ), $att_title ) ),
+						__( 'Restore' )
+					);
+				} elseif ( EMPTY_TRASH_DAYS && MEDIA_TRASH ) {
+					$actions['trash'] = sprintf(
+						'<a href="%s" class="submitdelete" aria-label="%s">%s</a>',
+						wp_nonce_url( "post.php?action=trash&amp;post=$post->ID", 'trash-post_' . $post->ID ),
+						/* translators: %s: attachment title */
+						esc_attr( sprintf( __( 'Move &#8220;%s&#8221; to the Trash' ), $att_title ) ),
+						_x( 'Trash', 'verb' )
+					);
+				}
+				if ( $this->is_trash || ! EMPTY_TRASH_DAYS || ! MEDIA_TRASH ) {
+					$delete_ays = ( !$this->is_trash && !MEDIA_TRASH ) ? " onclick='return showNotice.warn();'" : '';
+					$actions['delete'] = sprintf(
+						'<a href="%s" class="submitdelete"%s aria-label="%s">%s</a>',
+						wp_nonce_url( "post.php?action=delete&amp;post=$post->ID", 'delete-post_' . $post->ID ),
+						$delete_ays,
+						/* translators: %s: attachment title */
+						esc_attr( sprintf( __( 'Delete &#8220;%s&#8221; permanently' ), $att_title ) ),
+						__( 'Delete Permanently' )
+					);
+				}
+			}
+			if ( ! $this->is_trash ) {
+				$actions['view'] = sprintf(
+					'<a href="%s" aria-label="%s" rel="permalink">%s</a>',
+					get_permalink( $post->ID ),
+					/* translators: %s: attachment title */
+					esc_attr( sprintf( __( 'View &#8220;%s&#8221;' ), $att_title ) ),
+					__( 'View' )
+				);
 			}
 		}
 
