@@ -14,8 +14,7 @@
 
 /**
  * @since 2.1.0
- * @deprecated 2.1.0
- * @deprecated Use wp_editor().
+ * @deprecated 2.1.0 Use wp_editor()
  * @see wp_editor()
  */
 function tinymce_include() {
@@ -39,8 +38,7 @@ function documentation_link() {
  * Calculates the new dimensions for a downsampled image.
  *
  * @since 2.0.0
- * @deprecated 3.0.0
- * @deprecated Use wp_constrain_dimensions()
+ * @deprecated 3.0.0 Use wp_constrain_dimensions()
  * @see wp_constrain_dimensions()
  *
  * @param int $width Current width of the image
@@ -58,8 +56,7 @@ function wp_shrink_dimensions( $width, $height, $wmax = 128, $hmax = 96 ) {
  * Calculated the new dimensions for a downsampled image.
  *
  * @since 2.0.0
- * @deprecated 3.5.0
- * @deprecated Use wp_constrain_dimensions()
+ * @deprecated 3.5.0 Use wp_constrain_dimensions()
  * @see wp_constrain_dimensions()
  *
  * @param int $width Current width of the image
@@ -72,16 +69,15 @@ function get_udims( $width, $height ) {
 }
 
 /**
- * {@internal Missing Short Description}}
+ * Legacy function used to generate the categories checklist control.
  *
  * @since 0.71
- * @deprecated 2.6.0
- * @deprecated Use wp_category_checklist()
+ * @deprecated 2.6.0 Use wp_category_checklist()
  * @see wp_category_checklist()
  *
- * @param int $default
- * @param int $parent
- * @param array $popular_ids
+ * @param int $default       Unused.
+ * @param int $parent        Unused.
+ * @param array $popular_ids Unused.
  */
 function dropdown_categories( $default = 0, $parent = 0, $popular_ids = array() ) {
 	_deprecated_function( __FUNCTION__, '2.6', 'wp_category_checklist()' );
@@ -90,14 +86,13 @@ function dropdown_categories( $default = 0, $parent = 0, $popular_ids = array()
 }
 
 /**
- * {@internal Missing Short Description}}
+ * Legacy function used to generate a link categories checklist control.
  *
  * @since 2.1.0
- * @deprecated 2.6.0
- * @deprecated Use wp_link_category_checklist()
+ * @deprecated 2.6.0 Use wp_link_category_checklist()
  * @see wp_link_category_checklist()
  *
- * @param int $default
+ * @param int $default Unused.
  */
 function dropdown_link_categories( $default = 0 ) {
 	_deprecated_function( __FUNCTION__, '2.6', 'wp_link_category_checklist()' );
@@ -122,19 +117,18 @@ function get_real_file_to_edit( $file ) {
 }
 
 /**
- * {@internal Missing Short Description}}
+ * Legacy function used for generating a categories drop-down control.
  *
  * @since 1.2.0
- * @deprecated 3.0.0
- * @deprecated Use wp_dropdown_categories()
+ * @deprecated 3.0.0 Use wp_dropdown_categories()
  * @see wp_dropdown_categories()
  *
- * @param int $currentcat
- * @param int $currentparent
- * @param int $parent
- * @param int $level
- * @param array $categories
- * @return bool|null
+ * @param int $currentcat    Optional. ID of the current category. Default 0.
+ * @param int $currentparent Optional. Current parent category ID. Default 0.
+ * @param int $parent        Optional. Parent ID to retrieve categories for. Default 0.
+ * @param int $level         Optional. Number of levels deep to display. Default 0.
+ * @param array $categories  Optional. Categories to include in the control. Default 0.
+ * @return bool|null False if no categories were found.
  */
 function wp_dropdown_cats( $currentcat = 0, $currentparent = 0, $parent = 0, $level = 0, $categories = 0 ) {
 	_deprecated_function( __FUNCTION__, '3.0', 'wp_dropdown_categories()' );
@@ -162,8 +156,7 @@ function wp_dropdown_cats( $currentcat = 0, $currentparent = 0, $parent = 0, $le
  * Register a setting and its sanitization callback
  *
  * @since 2.7.0
- * @deprecated 3.0.0
- * @deprecated Use register_setting()
+ * @deprecated 3.0.0 Use register_setting()
  * @see register_setting()
  *
  * @param string $option_group A settings group name. Should correspond to a whitelisted option key name.
@@ -180,8 +173,7 @@ function add_option_update_handler( $option_group, $option_name, $sanitize_callb
  * Unregister a setting
  *
  * @since 2.7.0
- * @deprecated 3.0.0
- * @deprecated Use unregister_setting()
+ * @deprecated 3.0.0 Use unregister_setting()
  * @see unregister_setting()
  *
  * @param string $option_group
@@ -226,7 +218,9 @@ function use_codepress() {
 }
 
 /**
- * @deprecated 3.1.0
+ * Get all user IDs.
+ *
+ * @deprecated 3.1.0 Use get_users()
  *
  * @return array List of user IDs.
  */
@@ -243,7 +237,9 @@ function get_author_user_ids() {
 }
 
 /**
- * @deprecated 3.1.0
+ * Gets author users who can edit posts.
+ *
+ * @deprecated 3.1.0 Use get_users()
  *
  * @param int $user_id User ID.
  * @return array|bool List of editable authors. False if no editable users.
@@ -266,11 +262,13 @@ function get_editable_authors( $user_id ) {
 }
 
 /**
- * @deprecated 3.1.0
+ * Gets the IDs of any users who can edit posts.
  *
- * @param int $user_id User ID.
- * @param bool $exclude_zeros Optional, default is true. Whether to exclude zeros.
- * @return mixed
+ * @deprecated 3.1.0 Use get_users()
+ *
+ * @param int  $user_id       User ID.
+ * @param bool $exclude_zeros Optional. Whether to exclude zeroes. Default true.
+ * @return array Array of editable user IDs, empty array otherwise.
  */
 function get_editable_user_ids( $user_id, $exclude_zeros = true, $post_type = 'post' ) {
 	_deprecated_function( __FUNCTION__, '3.1', 'get_users()' );
@@ -301,7 +299,9 @@ function get_editable_user_ids( $user_id, $exclude_zeros = true, $post_type = 'p
 }
 
 /**
- * @deprecated 3.1.0
+ * Gets all users who are not authors.
+ *
+ * @deprecated 3.1.0 Use get_users()
  */
 function get_nonauthor_user_ids() {
 	_deprecated_function( __FUNCTION__, '3.1', 'get_users()' );
@@ -316,12 +316,12 @@ function get_nonauthor_user_ids() {
 	return $wpdb->get_col( $wpdb->prepare("SELECT user_id FROM $wpdb->usermeta WHERE meta_key = %s AND meta_value = '0'", $level_key) );
 }
 
-if ( !class_exists('WP_User_Search') ) :
+if ( ! class_exists( 'WP_User_Search', false ) ) :
 /**
  * WordPress User Search class.
  *
  * @since 2.1.0
- * @deprecated 3.1.0
+ * @deprecated 3.1.0 Use WP_User_Query
  */
 class WP_User_Search {
 
@@ -507,14 +507,12 @@ class WP_User_Search {
 	}
 
 	/**
-	 * {@internal Missing Short Description}}
-	 *
-	 * {@internal Missing Long Description}}
+	 * Prepares the user search query (legacy).
 	 *
 	 * @since 2.1.0
 	 * @access public
 	 */
-	function prepare_query() {
+	public function prepare_query() {
 		global $wpdb;
 		$this->first_user = ($this->page - 1) * $this->users_per_page;
 
@@ -547,14 +545,12 @@ class WP_User_Search {
 	}
 
 	/**
-	 * {@internal Missing Short Description}}
-	 *
-	 * {@internal Missing Long Description}}
+	 * Executes the user search query.
 	 *
 	 * @since 2.1.0
 	 * @access public
 	 */
-	function query() {
+	public function query() {
 		global $wpdb;
 
 		$this->results = $wpdb->get_col("SELECT DISTINCT($wpdb->users.ID)" . $this->query_from . $this->query_where . $this->query_orderby . $this->query_limit);
@@ -566,9 +562,7 @@ class WP_User_Search {
 	}
 
 	/**
-	 * {@internal Missing Short Description}}
-	 *
-	 * {@internal Missing Long Description}}
+	 * Prepares variables for use in templates.
 	 *
 	 * @since 2.1.0
 	 * @access public
@@ -576,14 +570,12 @@ class WP_User_Search {
 	function prepare_vars_for_template_usage() {}
 
 	/**
-	 * {@internal Missing Short Description}}
-	 *
-	 * {@internal Missing Long Description}}
+	 * Handles paging for the user search query.
 	 *
 	 * @since 2.1.0
 	 * @access public
 	 */
-	function do_paging() {
+	public function do_paging() {
 		if ( $this->total_users_for_query > $this->users_per_page ) { // have to page the results
 			$args = array();
 			if ( ! empty($this->search_term) )
@@ -610,16 +602,14 @@ class WP_User_Search {
 	}
 
 	/**
-	 * {@internal Missing Short Description}}
-	 *
-	 * {@internal Missing Long Description}}
+	 * Retrieves the user search query results.
 	 *
 	 * @since 2.1.0
 	 * @access public
 	 *
 	 * @return array
 	 */
-	function get_results() {
+	public function get_results() {
 		return (array) $this->results;
 	}
 
@@ -668,15 +658,18 @@ class WP_User_Search {
 endif;
 
 /**
- * Retrieve editable posts from other users.
+ * Retrieves editable posts from other users.
  *
- * @deprecated 3.1.0
+ * @since 2.3.0
+ * @deprecated 3.1.0 Use get_posts()
+ * @see get_posts()
  *
- * @param int $user_id User ID to not retrieve posts from.
- * @param string $type Optional, defaults to 'any'. Post type to retrieve, can be 'draft' or 'pending'.
+ * @param int    $user_id User ID to not retrieve posts from.
+ * @param string $type    Optional. Post type to retrieve. Accepts 'draft', 'pending' or 'any' (all).
+ *                        Default 'any'.
  * @return array List of posts from others.
  */
-function get_others_unpublished_posts($user_id, $type='any') {
+function get_others_unpublished_posts( $user_id, $type = 'any' ) {
 	_deprecated_function( __FUNCTION__, '3.1' );
 
 	global $wpdb;
@@ -703,7 +696,8 @@ function get_others_unpublished_posts($user_id, $type='any') {
 /**
  * Retrieve drafts from other users.
  *
- * @deprecated 3.1.0
+ * @deprecated 3.1.0 Use get_posts()
+ * @see get_posts()
  *
  * @param int $user_id User ID.
  * @return array List of drafts from other users.
@@ -717,7 +711,8 @@ function get_others_drafts($user_id) {
 /**
  * Retrieve pending review posts from other users.
  *
- * @deprecated 3.1.0
+ * @deprecated 3.1.0 Use get_posts()
+ * @see get_posts()
  *
  * @param int $user_id User ID.
  * @return array List of posts with pending review post type from other users.
@@ -732,8 +727,7 @@ function get_others_pending($user_id) {
  * Output the QuickPress dashboard widget.
  *
  * @since 3.0.0
- * @deprecated 3.2.0
- * @deprecated Use wp_dashboard_quick_press()
+ * @deprecated 3.2.0 Use wp_dashboard_quick_press()
  * @see wp_dashboard_quick_press()
  */
 function wp_dashboard_quick_press_output() {
@@ -742,9 +736,10 @@ function wp_dashboard_quick_press_output() {
 }
 
 /**
+ * Outputs the TinyMCE editor.
+ *
  * @since 2.7.0
- * @deprecated 3.3.0
- * @deprecated Use wp_editor()
+ * @deprecated 3.3.0 Use wp_editor()
  * @see wp_editor()
  *
  * @staticvar int $num
@@ -754,7 +749,7 @@ function wp_tiny_mce( $teeny = false, $settings = false ) {
 
 	static $num = 1;
 
-	if ( ! class_exists('_WP_Editors' ) )
+	if ( ! class_exists( '_WP_Editors', false ) )
 		require_once( ABSPATH . WPINC . '/class-wp-editor.php' );
 
 	$editor_id = 'content' . $num++;
@@ -770,8 +765,9 @@ function wp_tiny_mce( $teeny = false, $settings = false ) {
 }
 
 /**
- * @deprecated 3.3.0
- * @deprecated Use wp_editor()
+ * Preloads TinyMCE dialogs.
+ *
+ * @deprecated 3.3.0 Use wp_editor()
  * @see wp_editor()
  */
 function wp_preload_dialogs() {
@@ -779,8 +775,9 @@ function wp_preload_dialogs() {
 }
 
 /**
- * @deprecated 3.3.0
- * @deprecated Use wp_editor()
+ * Prints TinyMCE editor JS.
+ *
+ * @deprecated 3.3.0 Use wp_editor()
  * @see wp_editor()
  */
 function wp_print_editor_js() {
@@ -788,8 +785,9 @@ function wp_print_editor_js() {
 }
 
 /**
- * @deprecated 3.3.0
- * @deprecated Use wp_editor()
+ * Handles quicktags.
+ *
+ * @deprecated 3.3.0 Use wp_editor()
  * @see wp_editor()
  */
 function wp_quicktags() {
@@ -800,8 +798,7 @@ function wp_quicktags() {
  * Returns the screen layout options.
  *
  * @since 2.8.0
- * @deprecated 3.3.0
- * @deprecated Use $current_screen->render_screen_layout()
+ * @deprecated 3.3.0 WP_Screen::render_screen_layout()
  * @see WP_Screen::render_screen_layout()
  */
 function screen_layout( $screen ) {
@@ -821,8 +818,7 @@ function screen_layout( $screen ) {
  * Returns the screen's per-page options.
  *
  * @since 2.8.0
- * @deprecated 3.3.0
- * @deprecated Use $current_screen->render_per_page_options()
+ * @deprecated 3.3.0 Use WP_Screen::render_per_page_options()
  * @see WP_Screen::render_per_page_options()
  */
 function screen_options( $screen ) {
@@ -842,8 +838,7 @@ function screen_options( $screen ) {
  * Renders the screen's help.
  *
  * @since 2.7.0
- * @deprecated 3.3.0
- * @deprecated Use $current_screen->render_screen_meta()
+ * @deprecated 3.3.0 Use WP_Screen::render_screen_meta()
  * @see WP_Screen::render_screen_meta()
  */
 function screen_meta( $screen ) {
@@ -855,47 +850,112 @@ function screen_meta( $screen ) {
  * Favorite actions were deprecated in version 3.2. Use the admin bar instead.
  *
  * @since 2.7.0
- * @deprecated 3.2.0
+ * @deprecated 3.2.0 Use WP_Admin_Bar
+ * @see WP_Admin_Bar
  */
 function favorite_actions() {
 	_deprecated_function( __FUNCTION__, '3.2', 'WP_Admin_Bar' );
 }
 
+/**
+ * Handles uploading an image.
+ *
+ * @deprecated 3.3.0 Use wp_media_upload_handler()
+ * @see wp_media_upload_handler()
+ *
+ * @return null|string
+ */
 function media_upload_image() {
 	_deprecated_function( __FUNCTION__, '3.3', 'wp_media_upload_handler()' );
 	return wp_media_upload_handler();
 }
 
+/**
+ * Handles uploading an audio file.
+ *
+ * @deprecated 3.3.0 Use wp_media_upload_handler()
+ * @see wp_media_upload_handler()
+ *
+ * @return null|string
+ */
 function media_upload_audio() {
 	_deprecated_function( __FUNCTION__, '3.3', 'wp_media_upload_handler()' );
 	return wp_media_upload_handler();
 }
 
+/**
+ * Handles uploading a video file.
+ *
+ * @deprecated 3.3.0 Use wp_media_upload_handler()
+ * @see wp_media_upload_handler()
+ *
+ * @return null|string
+ */
 function media_upload_video() {
 	_deprecated_function( __FUNCTION__, '3.3', 'wp_media_upload_handler()' );
 	return wp_media_upload_handler();
 }
 
+/**
+ * Handles uploading a generic file.
+ *
+ * @deprecated 3.3.0 Use wp_media_upload_handler()
+ * @see wp_media_upload_handler()
+ *
+ * @return null|string
+ */
 function media_upload_file() {
 	_deprecated_function( __FUNCTION__, '3.3', 'wp_media_upload_handler()' );
 	return wp_media_upload_handler();
 }
 
+/**
+ * Handles retrieving the insert-from-URL form for an image.
+ *
+ * @deprecated 3.3.0 Use wp_media_insert_url_form()
+ * @see wp_media_insert_url_form()
+ *
+ * @return string
+ */
 function type_url_form_image() {
 	_deprecated_function( __FUNCTION__, '3.3', "wp_media_insert_url_form('image')" );
 	return wp_media_insert_url_form( 'image' );
 }
 
+/**
+ * Handles retrieving the insert-from-URL form for an audio file.
+ *
+ * @deprecated 3.3.0 Use wp_media_insert_url_form()
+ * @see wp_media_insert_url_form()
+ *
+ * @return string
+ */
 function type_url_form_audio() {
 	_deprecated_function( __FUNCTION__, '3.3', "wp_media_insert_url_form('audio')" );
 	return wp_media_insert_url_form( 'audio' );
 }
 
+/**
+ * Handles retrieving the insert-from-URL form for a video file.
+ *
+ * @deprecated 3.3.0 Use wp_media_insert_url_form()
+ * @see wp_media_insert_url_form()
+ *
+ * @return string
+ */
 function type_url_form_video() {
 	_deprecated_function( __FUNCTION__, '3.3', "wp_media_insert_url_form('video')" );
 	return wp_media_insert_url_form( 'video' );
 }
 
+/**
+ * Handles retrieving the insert-from-URL form for a generic file.
+ *
+ * @deprecated 3.3.0 Use wp_media_insert_url_form()
+ * @see wp_media_insert_url_form()
+ *
+ * @return string
+ */
 function type_url_form_file() {
 	_deprecated_function( __FUNCTION__, '3.3', "wp_media_insert_url_form('file')" );
 	return wp_media_insert_url_form( 'file' );
@@ -907,9 +967,8 @@ function type_url_form_file() {
  * Creates an 'Overview' help tab.
  *
  * @since 2.7.0
- * @deprecated 3.3.0
- * @deprecated Use get_current_screen()->add_help_tab()
- * @see WP_Screen
+ * @deprecated 3.3.0 Use WP_Screen::add_help_tab()
+ * @see WP_Screen::add_help_tab()
  *
  * @param string    $screen The handle for the screen to add help to. This is usually the hook name returned by the add_*_page() functions.
  * @param string    $help   The content of an 'Overview' help tab.
@@ -924,11 +983,10 @@ function add_contextual_help( $screen, $help ) {
 }
 
 /**
- * Get the allowed themes for the current blog.
+ * Get the allowed themes for the current site.
  *
  * @since 3.0.0
- * @deprecated 3.4.0
- * @deprecated Use wp_get_themes()
+ * @deprecated 3.4.0 Use wp_get_themes()
  * @see wp_get_themes()
  *
  * @return array $themes Array of allowed themes.
@@ -947,10 +1005,11 @@ function get_allowed_themes() {
 }
 
 /**
- * {@internal Missing Short Description}}
+ * Retrieves a list of broken themes.
  *
  * @since 1.5.0
- * @deprecated 3.4.0
+ * @deprecated 3.4.0 Use wp_get_themes()
+ * @see wp_get_themes()
  *
  * @return array
  */
@@ -971,10 +1030,11 @@ function get_broken_themes() {
 }
 
 /**
- * {@internal Missing Short Description}}
+ * Retrieves information on the current active theme.
  *
  * @since 2.0.0
- * @deprecated 3.4.0
+ * @deprecated 3.4.0 Use wp_get_theme()
+ * @see wp_get_theme()
  *
  * @return WP_Theme
  */
@@ -985,7 +1045,9 @@ function current_theme_info() {
 }
 
 /**
- * This was once used to display an 'Insert into Post' button. Now it is deprecated and stubbed.
+ * This was once used to display an 'Insert into Post' button.
+ *
+ * Now it is deprecated and stubbed.
  *
  * @deprecated 3.5.0
  */
@@ -994,7 +1056,9 @@ function _insert_into_post_button( $type ) {
 }
 
 /**
- * This was once used to display a media button. Now it is deprecated and stubbed.
+ * This was once used to display a media button.
+ *
+ * Now it is deprecated and stubbed.
  *
  * @deprecated 3.5.0
  */
@@ -1003,10 +1067,11 @@ function _media_button($title, $icon, $type, $id) {
 }
 
 /**
- * Get an existing post and format it for editing.
+ * Gets an existing post and format it for editing.
  *
  * @since 2.0.0
- * @deprecated 3.5.0
+ * @deprecated 3.5.0 Use get_post()
+ * @see get_post()
  *
  * @param int $id
  * @return object
@@ -1018,11 +1083,11 @@ function get_post_to_edit( $id ) {
 }
 
 /**
- * Get the default page information to use.
+ * Gets the default page information to use.
  *
  * @since 2.5.0
- * @deprecated 3.5.0
- * @deprecated Use get_default_post_to_edit()
+ * @deprecated 3.5.0 Use get_default_post_to_edit()
+ * @see get_default_post_to_edit()
  *
  * @return WP_Post Post object containing all the default post data as attributes
  */
@@ -1038,8 +1103,7 @@ function get_default_page_to_edit() {
  * This was once used to create a thumbnail from an Image given a maximum side size.
  *
  * @since 1.2.0
- * @deprecated 3.5.0
- * @deprecated Use image_resize()
+ * @deprecated 3.5.0 Use image_resize()
  * @see image_resize()
  *
  * @param mixed $file Filename of the original image, Or attachment id.
@@ -1071,7 +1135,7 @@ function wp_nav_menu_locations_meta_box() {
  * and calling the 'upgrade' method.
  *
  * @since 2.7.0
- * @deprecated 3.7.0
+ * @deprecated 3.7.0 Use Core_Upgrader
  * @see Core_Upgrader
  */
 function wp_update_core($current, $feedback = '') {
@@ -1094,7 +1158,7 @@ function wp_update_core($current, $feedback = '') {
  * Unused since 2.8.0.
  *
  * @since 2.5.0
- * @deprecated 3.7.0
+ * @deprecated 3.7.0 Use Plugin_Upgrader
  * @see Plugin_Upgrader
  */
 function wp_update_plugin($plugin, $feedback = '') {
@@ -1116,7 +1180,7 @@ function wp_update_plugin($plugin, $feedback = '') {
  * Unused since 2.8.0.
  *
  * @since 2.7.0
- * @deprecated 3.7.0
+ * @deprecated 3.7.0 Use Theme_Upgrader
  * @see Theme_Upgrader
  */
 function wp_update_theme($theme, $feedback = '') {
@@ -1133,8 +1197,6 @@ function wp_update_theme($theme, $feedback = '') {
 /**
  * This was once used to display attachment links. Now it is deprecated and stubbed.
  *
- * {@internal Missing Short Description}}
- *
  * @since 2.0.0
  * @deprecated 3.7.0
  *
@@ -1144,45 +1206,93 @@ function the_attachment_links( $id = false ) {
 	_deprecated_function( __FUNCTION__, '3.7' );
 }
 
-/**#@+
+/**
  * Displays a screen icon.
  *
  * @since 2.7.0
  * @since 3.8.0 Screen icons are no longer used in WordPress. This function no longer produces output.
- * @deprecated 3.8.0
+ * @deprecated 3.8.0 Use get_screen_icon()
+ * @see get_screen_icon()
  */
 function screen_icon() {
 	echo get_screen_icon();
 }
+
+/**
+ * Retrieves the screen icon (no longer used in 3.8+).
+ *
+ * @deprecated 3.8.0
+ *
+ * @return string
+ */
 function get_screen_icon() {
 	return '<!-- Screen icons are no longer used as of WordPress 3.8. -->';
 }
-/**#@-*/
 
-/**#@+
+/**
  * Deprecated dashboard widget controls.
  *
  * @since 2.5.0
  * @deprecated 3.8.0
  */
 function wp_dashboard_incoming_links_output() {}
-function wp_dashboard_secondary_output() {}
-/**#@-*/
 
-/**#@+
+/**
+ * Deprecated dashboard secondary output.
+ *
+ * @deprecated 3.8.0
+ */
+function wp_dashboard_secondary_output() {}
+
+/**
  * Deprecated dashboard widget controls.
  *
  * @since 2.7.0
  * @deprecated 3.8.0
  */
 function wp_dashboard_incoming_links() {}
+
+/**
+ * Deprecated dashboard incoming links control.
+ *
+ * @deprecated 3.8.0
+ */
 function wp_dashboard_incoming_links_control() {}
+
+/**
+ * Deprecated dashboard plugins control.
+ *
+ * @deprecated 3.8.0
+ */
 function wp_dashboard_plugins() {}
+
+/**
+ * Deprecated dashboard primary control.
+ *
+ * @deprecated 3.8.0
+ */
 function wp_dashboard_primary_control() {}
+
+/**
+ * Deprecated dashboard recent comments control.
+ *
+ * @deprecated 3.8.0
+ */
 function wp_dashboard_recent_comments_control() {}
+
+/**
+ * Deprecated dashboard secondary section.
+ *
+ * @deprecated 3.8.0
+ */
 function wp_dashboard_secondary() {}
+
+/**
+ * Deprecated dashboard secondary control.
+ *
+ * @deprecated 3.8.0
+ */
 function wp_dashboard_secondary_control() {}
-/**#@-*/
 
 /**
  * This was once used to move child posts to a new parent.
@@ -1197,3 +1307,69 @@ function wp_dashboard_secondary_control() {}
 function _relocate_children( $old_ID, $new_ID ) {
 	_deprecated_function( __FUNCTION__, '3.9' );
 }
+
+/**
+ * Add a top-level menu page in the 'objects' section.
+ *
+ * This function takes a capability which will be used to determine whether
+ * or not a page is included in the menu.
+ *
+ * The function which is hooked in to handle the output of the page must check
+ * that the user has the required capability as well.
+ *
+ * @since 2.7.0
+ *
+ * @deprecated 4.5.0 Use add_menu_page()
+ * @see add_menu_page()
+ * @global int $_wp_last_object_menu
+ *
+ * @param string   $page_title The text to be displayed in the title tags of the page when the menu is selected.
+ * @param string   $menu_title The text to be used for the menu.
+ * @param string   $capability The capability required for this menu to be displayed to the user.
+ * @param string   $menu_slug  The slug name to refer to this menu by (should be unique for this menu).
+ * @param callable $function   The function to be called to output the content for this page.
+ * @param string   $icon_url   The url to the icon to be used for this menu.
+ * @return string The resulting page's hook_suffix.
+ */
+function add_object_page( $page_title, $menu_title, $capability, $menu_slug, $function = '', $icon_url = '') {
+	_deprecated_function( __FUNCTION__, '4.5', 'add_menu_page()' );
+
+	global $_wp_last_object_menu;
+
+	$_wp_last_object_menu++;
+
+	return add_menu_page($page_title, $menu_title, $capability, $menu_slug, $function, $icon_url, $_wp_last_object_menu);
+}
+
+/**
+ * Add a top-level menu page in the 'utility' section.
+ *
+ * This function takes a capability which will be used to determine whether
+ * or not a page is included in the menu.
+ *
+ * The function which is hooked in to handle the output of the page must check
+ * that the user has the required capability as well.
+ *
+ * @since 2.7.0
+ *
+ * @deprecated 4.5.0 Use add_menu_page()
+ * @see add_menu_page()
+ * @global int $_wp_last_utility_menu
+ *
+ * @param string   $page_title The text to be displayed in the title tags of the page when the menu is selected.
+ * @param string   $menu_title The text to be used for the menu.
+ * @param string   $capability The capability required for this menu to be displayed to the user.
+ * @param string   $menu_slug  The slug name to refer to this menu by (should be unique for this menu).
+ * @param callable $function   The function to be called to output the content for this page.
+ * @param string   $icon_url   The url to the icon to be used for this menu.
+ * @return string The resulting page's hook_suffix.
+ */
+function add_utility_page( $page_title, $menu_title, $capability, $menu_slug, $function = '', $icon_url = '') {
+	_deprecated_function( __FUNCTION__, '4.5', 'add_menu_page()' );
+
+	global $_wp_last_utility_menu;
+
+	$_wp_last_utility_menu++;
+
+	return add_menu_page($page_title, $menu_title, $capability, $menu_slug, $function, $icon_url, $_wp_last_utility_menu);
+}
