@@ -1,14 +1,15 @@
-/* global ajaxurl, tinymce, wpLinkL10n, setUserSetting, wpActiveEditor */
 var wpLink;
 
-( function( $ ) {
-	var editor, searchTimer, River, Query, correctedURL,
+( function( $, wpLinkL10n, wp ) {
+	var editor, searchTimer, River, Query, correctedURL, linkNode,
+		emailRegexp = /^[A-Z0-9._%+-]+@[A-Z0-9.-]+\.[A-Z]{2,4}$/i,
+		urlRegexp = /^(https?|ftp):\/\/[A-Z0-9.-]+\.[A-Z]{2,4}[^ "]*$/i,
 		inputs = {},
 		rivers = {},
 		isTouch = ( 'ontouchend' in document );
 
 	function getLink() {
-		return editor.dom.getParent( editor.selection.getNode(), 'a' );
+		return linkNode || editor.dom.getParent( editor.selection.getNode(), 'a[href]' );
 	}
 
 	wpLink = {
@@ -50,13 +51,12 @@ var wpLink;
 				event.preventDefault();
 				wpLink.update();
 			});
-			inputs.close.add( inputs.backdrop ).add( '#wp-link-cancel a' ).click( function( event ) {
+
+			inputs.close.add( inputs.backdrop ).add( '#wp-link-cancel button' ).click( function( event ) {
 				event.preventDefault();
 				wpLink.close();
 			});
 
-			$( '#wp-link-search-toggle' ).on( 'click', wpLink.toggleInternalLinking );
-
 			rivers.elements.on( 'river-select', wpLink.updateFields );
 
 			// Display 'hint' message when search field or 'query-results' box are focused
@@ -69,11 +69,9 @@ var wpLink;
 			} );
 
 			inputs.search.on( 'keyup input', function() {
-				var self = this;
-
 				window.clearTimeout( searchTimer );
 				searchTimer = window.setTimeout( function() {
-					wpLink.searchInternalLinks.call( self );
+					wpLink.searchInternalLinks();
 				}, 500 );
 			});
 
@@ -94,11 +92,12 @@ var wpLink;
 			}
 		},
 
-		open: function( editorId ) {
+		open: function( editorId, url, text, node ) {
 			var ed,
 				$body = $( document.body );
 
 			$body.addClass( 'modal-open' );
+			linkNode = node;
 
 			wpLink.range = null;
 
@@ -112,12 +111,12 @@ var wpLink;
 
 			this.textarea = $( '#' + window.wpActiveEditor ).get( 0 );
 
-			if ( typeof tinymce !== 'undefined' ) {
+			if ( typeof window.tinymce !== 'undefined' ) {
 				// Make sure the link wrapper is the last element in the body,
 				// or the inline editor toolbar may show above the backdrop.
 				$body.append( inputs.backdrop, inputs.wrap );
 
-				ed = tinymce.get( wpActiveEditor );
+				ed = window.tinymce.get( window.wpActiveEditor );
 
 				if ( ed && ! ed.isHidden() ) {
 					editor = ed;
@@ -125,8 +124,8 @@ var wpLink;
 					editor = null;
 				}
 
-				if ( editor && tinymce.isIE ) {
-					editor.windowManager.bookmark = editor.selection.getBookmark();
+				if ( editor && window.tinymce.isIE ) {
+					editor.windowManager.wplinkBookmark = editor.selection.getBookmark();
 				}
 			}
 
@@ -138,7 +137,7 @@ var wpLink;
 			inputs.wrap.show();
 			inputs.backdrop.show();
 
-			wpLink.refresh();
+			wpLink.refresh( url, text );
 
 			$( document ).trigger( 'wplink-open', inputs.wrap );
 		},
@@ -147,15 +146,15 @@ var wpLink;
 			return editor && ! editor.isHidden();
 		},
 
-		refresh: function() {
-			var text = '';
+		refresh: function( url, text ) {
+			var linkText = '';
 
 			// Refresh rivers (clear links, check visibility)
 			rivers.search.refresh();
 			rivers.recent.refresh();
 
 			if ( wpLink.isMCE() ) {
-				wpLink.mceRefresh();
+				wpLink.mceRefresh( url, text );
 			} else {
 				// For the Text editor the "Link text" field is always shown
 				if ( ! inputs.wrap.hasClass( 'has-text-field' ) ) {
@@ -164,11 +163,11 @@ var wpLink;
 
 				if ( document.selection ) {
 					// Old IE
-					text = document.selection.createRange().text || '';
+					linkText = document.selection.createRange().text || text || '';
 				} else if ( typeof this.textarea.selectionStart !== 'undefined' &&
 					( this.textarea.selectionStart !== this.textarea.selectionEnd ) ) {
 					// W3C
-					text = this.textarea.value.substring( this.textarea.selectionStart, this.textarea.selectionEnd ) || '';
+					text = this.textarea.value.substring( this.textarea.selectionStart, this.textarea.selectionEnd ) || text || '';
 				}
 
 				inputs.text.val( text );
@@ -182,7 +181,10 @@ var wpLink;
 				// Focus the URL field and highlight its contents.
 				// If this is moved above the selection changes,
 				// IE will show a flashing cursor over the dialog.
-				inputs.url.focus()[0].select();
+				window.setTimeout( function() {
+					inputs.url[0].select();
+					inputs.url.focus();
+				} );
 			}
 
 			// Load the most recent results if this is the first time opening the panel.
@@ -194,7 +196,7 @@ var wpLink;
 		},
 
 		hasSelectedText: function( linkNode ) {
-			var html = editor.selection.getContent();
+			var node, nodes, i, html = editor.selection.getContent();
 
 			// Partial html and not a fully selected anchor element
 			if ( /</.test( html ) && ( ! /^<a [^>]+>[^<]+<\/a>$/.test( html ) || html.indexOf('href=') === -1 ) ) {
@@ -202,14 +204,16 @@ var wpLink;
 			}
 
 			if ( linkNode ) {
-				var nodes = linkNode.childNodes, i;
+				nodes = linkNode.childNodes;
 
 				if ( nodes.length === 0 ) {
 					return false;
 				}
 
 				for ( i = nodes.length - 1; i >= 0; i-- ) {
-					if ( nodes[i].nodeType != 3 ) {
+					node = nodes[i];
+
+					if ( node.nodeType != 3 && ! window.tinymce.dom.BookmarkManager.isBookmarkNode( node ) ) {
 						return false;
 					}
 				}
@@ -218,24 +222,49 @@ var wpLink;
 			return true;
 		},
 
-		mceRefresh: function() {
-			var text,
-				selectedNode = editor.selection.getNode(),
-				linkNode = editor.dom.getParent( selectedNode, 'a[href]' ),
+		mceRefresh: function( searchStr, text ) {
+			var linkText, href,
+				linkNode = getLink(),
 				onlyText = this.hasSelectedText( linkNode );
 
 			if ( linkNode ) {
-				text = linkNode.innerText || linkNode.textContent;
-				inputs.url.val( editor.dom.getAttrib( linkNode, 'href' ) );
-				inputs.openInNewTab.prop( 'checked', '_blank' === editor.dom.getAttrib( linkNode, 'target' ) );
-				inputs.submit.val( wpLinkL10n.update );
+				linkText = linkNode.innerText || linkNode.textContent;
+				href = editor.dom.getAttrib( linkNode, 'href' );
+
+				if ( ! $.trim( linkText ) ) {
+					linkText = text || '';
+				}
+
+				if ( searchStr && ( urlRegexp.test( searchStr ) || emailRegexp.test( searchStr ) ) ) {
+					href = searchStr;
+				}
+
+				if ( href !== '_wp_link_placeholder' ) {
+					inputs.url.val( href );
+					inputs.openInNewTab.prop( 'checked', '_blank' === editor.dom.getAttrib( linkNode, 'target' ) );
+					inputs.submit.val( wpLinkL10n.update );
+				} else {
+					this.setDefaultValues( linkText );
+				}
+
+				if ( searchStr && searchStr !== href ) {
+					// The user has typed something in the inline dialog. Trigger a search with it.
+					inputs.search.val( searchStr );
+				} else {
+					inputs.search.val( '' );
+				}
+
+				// Always reset the search
+				window.setTimeout( function() {
+					wpLink.searchInternalLinks();
+				} );
 			} else {
-				text = editor.selection.getContent({ format: 'text' });
-				this.setDefaultValues();
+				linkText = editor.selection.getContent({ format: 'text' }) || text || '';
+				this.setDefaultValues( linkText );
 			}
 
 			if ( onlyText ) {
-				inputs.text.val( text || '' );
+				inputs.text.val( linkText );
 				inputs.wrap.addClass( 'has-text-field' );
 			} else {
 				inputs.text.val( '' );
@@ -243,18 +272,24 @@ var wpLink;
 			}
 		},
 
-		close: function() {
+		close: function( reset ) {
 			$( document.body ).removeClass( 'modal-open' );
 
-			if ( ! wpLink.isMCE() ) {
-				wpLink.textarea.focus();
+			if ( reset !== 'noReset' ) {
+				if ( ! wpLink.isMCE() ) {
+					wpLink.textarea.focus();
 
-				if ( wpLink.range ) {
-					wpLink.range.moveToBookmark( wpLink.range.getBookmark() );
-					wpLink.range.select();
+					if ( wpLink.range ) {
+						wpLink.range.moveToBookmark( wpLink.range.getBookmark() );
+						wpLink.range.select();
+					}
+				} else {
+					if ( editor.plugins.wplink ) {
+						editor.plugins.wplink.close();
+					}
+
+					editor.focus();
 				}
-			} else {
-				editor.focus();
 			}
 
 			inputs.backdrop.hide();
@@ -346,21 +381,23 @@ var wpLink;
 
 			wpLink.close();
 			textarea.focus();
+
+			// Audible confirmation message when a link has been inserted in the Editor.
+			wp.a11y.speak( wpLinkL10n.linkInserted );
 		},
 
 		mceUpdate: function() {
 			var attrs = wpLink.getAttrs(),
 				link, text;
 
-			wpLink.close();
-			editor.focus();
-
-			if ( tinymce.isIE ) {
-				editor.selection.moveToBookmark( editor.windowManager.bookmark );
+			if ( window.tinymce.isIE && editor.windowManager.wplinkBookmark ) {
+				editor.selection.moveToBookmark( editor.windowManager.wplinkBookmark );
+				editor.windowManager.wplinkBookmark = null;
 			}
 
 			if ( ! attrs.href ) {
 				editor.execCommand( 'unlink' );
+				wpLink.close();
 				return;
 			}
 
@@ -379,6 +416,8 @@ var wpLink;
 					}
 				}
 
+				// Not editing any more
+				attrs['data-wplink-edit'] = null;
 				editor.dom.setAttribs( link, attrs );
 			} else {
 				if ( text ) {
@@ -388,44 +427,56 @@ var wpLink;
 				}
 			}
 
+			wpLink.close( 'noReset' );
+			editor.focus();
 			editor.nodeChanged();
+
+			// Audible confirmation message when a link has been inserted in the Editor.
+			wp.a11y.speak( wpLinkL10n.linkInserted );
 		},
 
 		updateFields: function( e, li ) {
 			inputs.url.val( li.children( '.item-permalink' ).val() );
 		},
 
-		setDefaultValues: function() {
-			var selection,
-				emailRegexp = /^[A-Z0-9._%+-]+@[A-Z0-9.-]+\.[A-Z]{2,4}$/i,
-				urlRegexp = /^(https?|ftp):\/\/[A-Z0-9.-]+\.[A-Z]{2,4}[^ "]*$/i;
-
-			if ( this.isMCE() ) {
-				selection = editor.selection.getContent();
-			} else if ( document.selection && wpLink.range ) {
-				selection = wpLink.range.text;
-			} else if ( typeof this.textarea.selectionStart !== 'undefined' ) {
-				selection = this.textarea.value.substring( this.textarea.selectionStart, this.textarea.selectionEnd );
+		getUrlFromSelection: function( selection ) {
+			if ( ! selection ) {
+				if ( this.isMCE() ) {
+					selection = editor.selection.getContent({ format: 'text' });
+				} else if ( document.selection && wpLink.range ) {
+					selection = wpLink.range.text;
+				} else if ( typeof this.textarea.selectionStart !== 'undefined' ) {
+					selection = this.textarea.value.substring( this.textarea.selectionStart, this.textarea.selectionEnd );
+				}
 			}
 
+			selection = $.trim( selection );
+
 			if ( selection && emailRegexp.test( selection ) ) {
 				// Selection is email address
-				inputs.url.val( 'mailto:' + selection );
+				return 'mailto:' + selection;
 			} else if ( selection && urlRegexp.test( selection ) ) {
 				// Selection is URL
-				inputs.url.val( selection.replace( /&amp;|&#0?38;/gi, '&' ) );
-			} else {
-				// Set URL to default.
-				inputs.url.val( '' );
+				return selection.replace( /&amp;|&#0?38;/gi, '&' );
 			}
 
+			return '';
+		},
+
+		setDefaultValues: function( selection ) {
+			inputs.url.val( this.getUrlFromSelection( selection ) );
+
+			// Empty the search field and swap the "rivers".
+			inputs.search.val('');
+			wpLink.searchInternalLinks();
+
 			// Update save prompt.
 			inputs.submit.val( wpLinkL10n.save );
 		},
 
 		searchInternalLinks: function() {
-			var t = $( this ), waiting,
-				search = t.val();
+			var waiting,
+				search = inputs.search.val() || '';
 
 			if ( search.length > 2 ) {
 				rivers.recent.hide();
@@ -436,7 +487,7 @@ var wpLink;
 					return;
 
 				wpLink.lastSearch = search;
-				waiting = t.parent().find( '.spinner' ).addClass( 'is-active' );
+				waiting = inputs.search.parent().find( '.spinner' ).addClass( 'is-active' );
 
 				rivers.search.change( search );
 				rivers.search.ajax( function() {
@@ -527,15 +578,6 @@ var wpLink;
 				funcContext = this;
 				funcTriggered = true;
 			};
-		},
-
-		toggleInternalLinking: function( event ) {
-			var visible = inputs.wrap.hasClass( 'search-panel-visible' );
-
-			inputs.wrap.toggleClass( 'search-panel-visible', ! visible );
-			setUserSetting( 'wplink', visible ? '0' : '1' );
-			inputs[ ! visible ? 'search' : 'url' ].focus();
-			event.preventDefault();
 		}
 	};
 
@@ -712,7 +754,7 @@ var wpLink;
 
 			this.querying = true;
 
-			$.post( ajaxurl, query, function( r ) {
+			$.post( window.ajaxurl, query, function( r ) {
 				self.page++;
 				self.querying = false;
 				self.allLoaded = ! r;
@@ -722,4 +764,4 @@ var wpLink;
 	});
 
 	$( document ).ready( wpLink.init );
-})( jQuery );
+})( jQuery, window.wpLinkL10n, window.wp );
